<?php
    add_action( 'add_meta_boxes', 'bnai_cb_add_page_meta_box' );

    function bnai_cb_add_page_meta_box() {
        add_meta_box( 'bnai_cb_page_options', // ID attribute of metabox
                          __('Chatbot Botnation Options', 'chatbot-botnation'),       // Title of metabox visible to user
                          'bnai_cb_draw_page_options', // Function that prints box in wp-admin
                          'page',              // Show box for posts, pages, custom, etc.
                          'side',            // Where on the page to show the box
                          'default' );
    }

    add_action('load-post.php', 'bnai_cb_enable_help');

    function bnai_cb_generate_help_line($name, $desc) {
        return  '<p><strong>' . $name . '</strong>' . $desc . '</p>';
    }

    // Add help tab on edit page.
    function bnai_cb_enable_help() {
        // Add help tab
        $screen = get_current_screen();
        if ($screen->id != 'page') return;
        $screen->add_help_tab( array(
           'id' => 'bnai_cb_page_help_tab',            //unique id for the tab
           'title' =>  __('Chatbot Botnation', 'chatbot-botnation'),      //unique visible title for the tab
           'content' => bnai_cb_generate_help_line(__('Open automatically the chat (force)', 'chatbot-botnation'), __(' - If enabled, the chat will start automatically on this page.', 'chatbot-botnation'))
                 . bnai_cb_generate_help_line(__('Restart the conversation on sequence', 'chatbot-botnation'), __(' - You can start a specific sequence for this page by :', 'chatbot-botnation'))
                 . '<ul>'
                 . '<li>' . sprintf(__('Setting &laquo;%s&raquo; to restart your welcome sequence.','chatbot-botnation'), '<strong>restart</strong>') . '</li>'
                 . '<li>' . __('copying / pasting the ID of the sequence you want to start :','chatbot-botnation')
                 . '<div><img src="' .  esc_url(plugins_url('images/bnai-cb-help-ref.png', dirname(__FILE__))) . '" title="' . __('How to start a specific sequence', 'chatbot-botnation') . '"/></div>'
                 . '</li>'
                 . '</ul>'
        ) );
    }

    function bnai_cb_draw_page_options($post) {
        $values = get_post_custom( $post->ID );
        $auto_start = isset( $values[BNAI_CB_POST_CUSTOM_FIELD_AUTO_START] ) ? $values[BNAI_CB_POST_CUSTOM_FIELD_AUTO_START][0] : 0;
        $ref = isset( $values[BNAI_CB_POST_CUSTOM_FIELD_REF] ) ? $values[BNAI_CB_POST_CUSTOM_FIELD_REF][0] : '';

        wp_nonce_field( 'bnai_cb_page_meta_box_nonce_name', 'bnai_cb_nonce' );
        ?>
            <div class="wrap">
                  <input id="bnai_cb_page_auto_start_input" name="bnai_cb_page_auto_start_input" value="1" type="hidden" />
                  <label for="bnai_cb_page_auto_start">

                      <input id="bnai_cb_page_auto_start"
                             name="bnai_cb_page_auto_start"
                             type="checkbox"
                             value="1"
                             <?php echo isset( $auto_start ) ? ( checked( $auto_start, "1", true )) : ( '' ); ?> />
                     <?php esc_html_e( 'Open automatically the chat (force).', 'chatbot-botnation' ); ?>
                  </label>
              </div>
              <div class="wrap">
                    <label for="bnai_cb_page_ref">
                       <?php esc_html_e( 'Restart the conversation on sequence', 'chatbot-botnation' ); ?>
                    </label>

                    <input id="bnai_cb_page_ref"
                       class="regular-text"
                       name="bnai_cb_page_ref"
                       type="text"
                       style="width: 100%;"
                       value="<?php echo $ref; ?>" />
                </div>
                <p>
                    <?php echo __("Need help? Use the Help tab above the screen title.", 'chatbot-botnation'); ?>
                </p>
        <?php
    }

    add_action( 'save_post', 'bnai_cb_meta_box_post_save' );

    function bnai_cb_meta_box_post_save($post_id) {
        // Bail if we're doing an auto save
        if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;

        // if our nonce isn't there, or we can't verify it, bail
        if( !isset( $_POST['bnai_cb_nonce'] ) || !wp_verify_nonce( $_POST['bnai_cb_nonce'], 'bnai_cb_page_meta_box_nonce_name' ) ) return;

        // if our current user can't edit this post, bail
        if( !current_user_can( 'edit_post' ) ) return;

        if( isset( $_POST['bnai_cb_page_auto_start_input']) ) update_post_meta( $post_id, BNAI_CB_POST_CUSTOM_FIELD_AUTO_START, $_POST['bnai_cb_page_auto_start'] );
        if( isset( $_POST['bnai_cb_page_ref'] ) ) update_post_meta( $post_id, BNAI_CB_POST_CUSTOM_FIELD_REF, $_POST['bnai_cb_page_ref'] );
    }
?>